pub unsafe extern "C" fn nix_create_external_value(
context: *mut nix_c_context,
desc: *mut NixCExternalValueDesc,
v: *mut c_void,
) -> *mut ExternalValueExpand description
Create an external value, that can be given to nix_init_external Call nix_gc_decref() when you’re done with the pointer.
Arguments
context[out] - Optional, stores error informationdesc[in] - a NixCExternalValueDesc, you should keep this alive as long as the ExternalValue livesv[in] - the value to store
Returns
external value, owned by the garbage collector