nix_flake_lock_flags_set_mode_virtual

Function nix_flake_lock_flags_set_mode_virtual 

pub unsafe extern "C" fn nix_flake_lock_flags_set_mode_virtual(
    context: *mut nix_c_context,
    flags: *mut nix_flake_lock_flags,
) -> nix_err
Put the lock flags in a mode that updates the lock file in memory, if needed.

Arguments

  • context [out] - Optional, stores error information
  • flags [in] - The flags to modify
  • update [in] - Whether to allow updates This will cause nix_flake_lock to update the lock file in memory, if needed.