pub unsafe extern "C" fn nix_gc_incref(
context: *mut nix_c_context,
object: *const c_void,
) -> nix_errExpand description
Increment the garbage collector reference counter for the given object. The Nix language evaluator C API keeps track of alive objects by reference counting. When you’re done with a refcounted pointer, call nix_gc_decref().
Arguments
context[out] - Optional, stores error informationobject[in] - The object to keep alive