pub unsafe extern "C" fn nix_gc_now()Expand description
Trigger the garbage collector manually You should not need to do this, but it can be useful for debugging.
pub unsafe extern "C" fn nix_gc_now()Trigger the garbage collector manually You should not need to do this, but it can be useful for debugging.