nix_get_external_value_content

Function nix_get_external_value_content 

pub unsafe extern "C" fn nix_get_external_value_content(
    context: *mut nix_c_context,
    b: *mut ExternalValue,
) -> *mut c_void
Extract the pointer from a Nix C API external value.

Arguments

  • context [out] - Optional, stores error information
  • b [in] - The external value

Returns

The pointer, valid while the external value is valid, or null if the external value was not from the Nix C API.

See also

nix_get_external