pub unsafe extern "C" fn nix_get_list_byidx_lazy(
context: *mut nix_c_context,
value: *const nix_value,
state: *mut EvalState,
ix: c_uint,
) -> *mut nix_valueExpand description
Get the ix’th element of a list without forcing evaluation of the element @ingroup value_extract Returns the list element without forcing its evaluation, allowing access to lazy values. The list value itself must already be evaluated. Call nix_value_decref() when you’re done with the pointer
Arguments
context[out] - Optional, stores error informationvalue[in] - Nix value to inspect (must be an evaluated list)state[in] - nix evaluator stateix[in] - list element to get
Returns
value, NULL in case of errors