nix_locked_flake_export_json

Function nix_locked_flake_export_json 

pub unsafe extern "C" fn nix_locked_flake_export_json(
    context: *mut nix_c_context,
    locked_flake: *mut nix_locked_flake,
    callback: nix_get_string_callback,
    user_data: *mut c_void,
) -> nix_err
Export a locked flake as an owned JSON graph. The returned JSON contains the lock file and the source paths that Nix keeps alongside the lock graph for local or overridden inputs.