nix_make_attrs

Function nix_make_attrs 

pub unsafe extern "C" fn nix_make_attrs(
    context: *mut nix_c_context,
    value: *mut nix_value,
    b: *mut BindingsBuilder,
) -> nix_err
Create an attribute set from a bindings builder @ingroup value_create After this call, the bindings builder becomes invalid and cannot be used again. The only necessary next step is to free it with nix_bindings_builder_free().

Arguments

  • context [out] - Optional, stores error information
  • value [out] - Nix value to modify
  • b [in] - bindings builder to use

Returns

error code, NIX_OK on success.

See also

nix_bindings_builder_free