nix_make_list

Function nix_make_list 

pub unsafe extern "C" fn nix_make_list(
    context: *mut nix_c_context,
    list_builder: *mut ListBuilder,
    value: *mut nix_value,
) -> nix_err
Create a list from a list builder @ingroup value_create After this call, the list builder becomes invalid and cannot be used again. The only necessary next step is to free it with nix_list_builder_free().

Arguments

  • context [out] - Optional, stores error information
  • list_builder [in] - list builder to use
  • value [out] - Nix value to modify

Returns

error code, NIX_OK on success.

See also

nix_list_builder_free