nix_store_create_from_parts

Function nix_store_create_from_parts 

pub unsafe extern "C" fn nix_store_create_from_parts(
    context: *mut nix_c_context,
    hash: *const nix_store_path_hash_part,
    name: *const c_char,
    name_len: usize,
) -> *mut StorePath
Create a StorePath from its constituent parts (hash and name) This function constructs a store path from a hash and name, without needing a Store reference or the store directory prefix.

Note Don’t forget to free this path using nix_store_path_free()!

Arguments

  • context [out] - Optional, stores error information
  • hash [in] - The store path hash (20 raw bytes)
  • name [in] - The store path name (the part after the hash)
  • name_len [in] - Length of the name string

Returns

owned store path, NULL on error