nix_store_get_fs_closure

Function nix_store_get_fs_closure 

pub unsafe extern "C" fn nix_store_get_fs_closure(
    context: *mut nix_c_context,
    store: *mut Store,
    store_path: *const StorePath,
    flip_direction: bool,
    include_outputs: bool,
    include_derivers: bool,
    userdata: *mut c_void,
    callback: Option<unsafe extern "C" fn(context: *mut nix_c_context, userdata: *mut c_void, store_path: *const StorePath)>,
) -> nix_err
Gets the closure of a specific store path

Note The callback borrows each StorePath only for the duration of the call.

Arguments

  • context [out] - Optional, stores error information
  • store [in] - nix store reference
  • store_path [in] - The path to compute from
  • flip_direction [in] - If false, compute the forward closure (paths referenced by any store path in the closure). If true, compute the backward closure (paths that reference any store path in the closure).
  • include_outputs [in] - If flip_direction is false: for any derivation in the closure, include its outputs. If flip_direction is true: for any output in the closure, include derivations that produce it.
  • include_derivers [in] - If flip_direction is false: for any output in the closure, include the derivation that produced it. If flip_direction is true: for any derivation in the closure, include its outputs.
  • callback [in] - The function to call for every store path, in no particular order
  • userdata [in] - The userdata to pass to the callback