nix_store_query_path_from_hash_part

Function nix_store_query_path_from_hash_part 

pub unsafe extern "C" fn nix_store_query_path_from_hash_part(
    context: *mut nix_c_context,
    store: *mut Store,
    hash: *const c_char,
) -> *mut StorePath
Query the full store path given the hash part of a valid store path, or empty if no matching path is found.

Arguments

  • context [out] - Optional, stores error information
  • store [in] - nix store reference
  • hash [in] - Hash part of path as a string

Returns

Store path reference, NULL if no matching path is found.