pub unsafe extern "C" fn nix_store_realise(
context: *mut nix_c_context,
store: *mut Store,
path: *mut StorePath,
userdata: *mut c_void,
callback: Option<unsafe extern "C" fn(userdata: *mut c_void, outname: *const c_char, out: *const StorePath)>,
) -> nix_errExpand description
Realise a Nix store path Blocking, calls callback once for each realised output.
Note When working with expressions, consider using e.g. nix_string_realise to get the output.
.drvPathmay not be accurate or available in the future. See https://github.com/NixOS/nix/issues/6507
Arguments
context[out] - Optional, stores error informationstore[in] - Nix Store referencepath[in] - Path to builduserdata[in] - data to pass to every callback invocationcallback[in] - called for every realised output
Returns
NIX_OK if the build succeeded, or an error code if the build/scheduling/outputs/copying/etc failed. On error, the callback is never invoked and error information is stored in context.