pub unsafe extern "C" fn nix_value_call(
context: *mut nix_c_context,
state: *mut EvalState,
fn_: *mut nix_value,
arg: *mut nix_value,
value: *mut nix_value,
) -> nix_errExpand description
Calls a Nix function with an argument. @ingroup value_create
Arguments
context[out] - Optional, stores error informationstate[in] - The state of the evaluation.fn[in] - The Nix function to call.arg[in] - The argument to pass to the function.value[out] - The result of the function call.
Returns
NIX_OK if the function call was successful, an error code otherwise.
See also
nix_init_apply()for a similar function that does not performs the call immediately, but stores it as a thunk. Note the different argument order.