pub unsafe extern "C" fn nix_value_call_multi(
context: *mut nix_c_context,
state: *mut EvalState,
fn_: *mut nix_value,
nargs: usize,
args: *mut *mut nix_value,
value: *mut nix_value,
) -> nix_errExpand description
Calls a Nix function with multiple arguments. @ingroup value_create Technically these are functions that return functions. It is common for Nix functions to be curried, so this function is useful for calling them.
Arguments
context[out] - Optional, stores error informationstate[in] - The state of the evaluation.fn[in] - The Nix function to call.nargs[in] - The number of arguments.args[in] - The arguments to pass to the function.value[out] - The result of the function call.
See also
nix_value_callFor the single argument primitive. [NIX_VALUE_CALL] For a macro that wraps this function for convenience.