pub unsafe extern "C" fn nix_value_force_deep(
context: *mut nix_c_context,
state: *mut EvalState,
value: *mut nix_value,
) -> nix_errExpand description
Forces the deep evaluation of a Nix value. Recursively calls nix_value_force
See also
nix_value_force@warning Calling this function on a recursive data structure will cause a stack overflow.
Arguments
context[out] - Optional, stores error informationstate[in] - The state of the evaluation.value[in,out] - The Nix value to force.
Returns
NIX_OK if the deep force operation was successful, an error code otherwise.