Function nix_flake_lock_flags_set_mode_check
Source pub unsafe extern "C" fn nix_flake_lock_flags_set_mode_check(
context: *mut nix_c_context,
flags: *mut nix_flake_lock_flags,
) -> nix_err
Put the lock flags in a mode that checks whether the lock is up to date.
Arguments
context [out] - Optional, stores error information
flags [in] - The flags to modify
Returns
NIX_OK on success, NIX_ERR on failure
This causes nix_flake_lock to fail if the lock needs to be updated.