pub unsafe extern "C" fn nix_flake_lock_flags_set_mode_virtual(
context: *mut nix_c_context,
flags: *mut nix_flake_lock_flags,
) -> nix_errExpand description
Put the lock flags in a mode that updates the lock file in memory, if needed.
Arguments
context[out] - Optional, stores error informationflags[in] - The flags to modifyupdate[in] - Whether to allow updates This will causenix_flake_lockto update the lock file in memory, if needed.