pub unsafe extern "C" fn nix_get_attr_byname_lazy(
context: *mut nix_c_context,
value: *const nix_value,
state: *mut EvalState,
name: *const c_char,
) -> *mut nix_valueExpand description
Get an attribute value by attribute name, without forcing evaluation of the attribute’s value @ingroup value_extract Returns the attribute value without forcing its evaluation, allowing access to lazy values. The attribute set value itself must already be evaluated. Call nix_value_decref() when you’re done with the pointer
Arguments
context[out] - Optional, stores error informationvalue[in] - Nix value to inspect (must be an evaluated attribute set)state[in] - nix evaluator statename[in] - attribute name
Returns
value, NULL in case of errors