pub unsafe extern "C" fn nix_get_attr_name_byidx(
context: *mut nix_c_context,
value: *mut nix_value,
state: *mut EvalState,
i: c_uint,
) -> *const c_charExpand description
Get an attribute name by index @ingroup value_extract Returns the attribute name without forcing evaluation of the attribute’s value. Attributes are returned in an unspecified order which is NOT suitable for reproducible operations. In Nix’s domain, reproducibility is paramount. The caller is responsible for sorting the attributes or storing them in an ordered map to ensure deterministic behavior in your application.
Note When Nix does sort attributes, which it does for virtually all intermediate operations and outputs, it uses byte-wise lexicographic order (equivalent to lexicographic order by Unicode scalar value for valid UTF-8). We recommend applying this same ordering for consistency.
Arguments
context[out] - Optional, stores error informationvalue[in] - Nix value to inspectstate[in] - nix evaluator statei[in] - attribute index
Returns
name string valid until state is freed, NULL in case of errors