pub unsafe extern "C" fn nix_locked_flake_import_json(
context: *mut nix_c_context,
fetch_settings: *mut nix_fetchers_settings,
json: *const c_char,
json_len: usize,
) -> *mut nix_locked_flakeExpand description
Import a locked flake from an owned JSON graph. This reconstructs the locked graph without resolving the flake reference, writing a lock file, or updating inputs. The returned value is intended for nix_locked_flake_get_output_attrs.