pub unsafe extern "C" fn nix_make_list(
context: *mut nix_c_context,
list_builder: *mut ListBuilder,
value: *mut nix_value,
) -> nix_errExpand description
Create a list from a list builder @ingroup value_create After this call, the list builder becomes invalid and cannot be used again. The only necessary next step is to free it with nix_list_builder_free().
Arguments
context[out] - Optional, stores error informationlist_builder[in] - list builder to usevalue[out] - Nix value to modify
Returns
error code, NIX_OK on success.