pub unsafe extern "C" fn nix_store_query_path_from_hash_part(
context: *mut nix_c_context,
store: *mut Store,
hash: *const c_char,
) -> *mut StorePathExpand description
Query the full store path given the hash part of a valid store path, or empty if no matching path is found.
Arguments
context[out] - Optional, stores error informationstore[in] - nix store referencehash[in] - Hash part of path as a string
Returns
Store path reference, NULL if no matching path is found.