pub unsafe extern "C" fn nix_value_decref(
context: *mut nix_c_context,
value: *mut nix_value,
) -> nix_errExpand description
Decrement the garbage collector reference counter for the given object
@ingroup value
When the counter reaches zero, the nix_value object becomes invalid.
The data referenced by nix_value may not be deallocated until the memory
garbage collector has run, but deallocation is not guaranteed.
Arguments
context[out] - Optional, stores error informationvalue[in] - The object to stop referencing